Files
MINGW-packages/mingw-w64-nodejs/0001-fix-python-2-shebang.patch
2016-09-14 22:06:55 +02:00

2022 lines
83 KiB
Diff

From 6f873bddb7f8696eca6790dc7a0f8d4a27fa0c93 Mon Sep 17 00:00:00 2001
From: mati865 <mati865@gmail.com>
Date: Thu, 8 Sep 2016 13:58:08 +0200
Subject: [PATCH 01/13] fix python 2 shebang
---
common.gypi | 2 +-
configure | 2 +-
deps/cares/build/gcc_version.py | 2 +-
deps/cares/gyp_cares | 2 +-
.../node-gyp/gyp/buildbot/buildbot_run.py | 2 +-
deps/npm/node_modules/node-gyp/gyp/gyp | 2 +-
deps/npm/node_modules/node-gyp/gyp/gyp_main.py | 2 +-
deps/npm/node_modules/node-gyp/gyp/gyptest.py | 2 +-
.../node-gyp/gyp/pylib/gyp/MSVSSettings_test.py | 2 +-
.../node-gyp/gyp/pylib/gyp/__init__.py | 2 +-
.../node-gyp/gyp/pylib/gyp/common_test.py | 2 +-
.../node-gyp/gyp/pylib/gyp/easy_xml_test.py | 2 +-
.../node-gyp/gyp/pylib/gyp/flock_tool.py | 2 +-
.../node-gyp/gyp/pylib/gyp/generator/msvs_test.py | 2 +-
.../node-gyp/gyp/pylib/gyp/generator/ninja.py | 2 +-
.../node-gyp/gyp/pylib/gyp/generator/ninja_test.py | 2 +-
.../node-gyp/gyp/pylib/gyp/generator/xcode.py | 2 +-
.../node-gyp/gyp/pylib/gyp/generator/xcode_test.py | 2 +-
.../node-gyp/gyp/pylib/gyp/input_test.py | 2 +-
.../node-gyp/gyp/pylib/gyp/mac_tool.py | 2 +-
.../node-gyp/gyp/pylib/gyp/win_tool.py | 4 ++--
deps/npm/node_modules/node-gyp/gyp/samples/samples | 2 +-
deps/npm/node_modules/node-gyp/gyp/setup.py | 2 +-
.../node-gyp/gyp/tools/emacs/testdata/media.gyp | 2 +-
.../gyp/tools/emacs/testdata/media.gyp.fontified | 2 +-
.../node_modules/node-gyp/gyp/tools/graphviz.py | 2 +-
.../node_modules/node-gyp/gyp/tools/pretty_gyp.py | 2 +-
.../node_modules/node-gyp/gyp/tools/pretty_sln.py | 2 +-
.../node-gyp/gyp/tools/pretty_vcproj.py | 2 +-
deps/npm/node_modules/node-gyp/lib/configure.js | 4 ++--
.../node_modules/node-gyp/test/test-find-python.js | 2 +-
deps/uv/gyp_uv.py | 2 +-
deps/v8/DEPS | 14 ++++++-------
deps/v8/Makefile | 2 +-
deps/v8/Makefile.android | 2 +-
deps/v8/Makefile.nacl | 2 +-
deps/v8/build/coverage_wrapper.py | 2 +-
deps/v8/build/detect_v8_host_arch.py | 2 +-
deps/v8/build/download_gold_plugin.py | 4 ++--
deps/v8/build/get_landmines.py | 2 +-
deps/v8/build/gyp_v8 | 2 +-
deps/v8/build/has_valgrind.py | 2 +-
deps/v8/build/isolate.gypi | 2 +-
deps/v8/build/landmines.py | 2 +-
deps/v8/build/shim_headers.gypi | 2 +-
deps/v8/build/standalone.gypi | 2 +-
deps/v8/build/toolchain.gypi | 2 +-
deps/v8/build/vs_toolchain.py | 2 +-
deps/v8/src/d8.gyp | 2 +-
deps/v8/tools/android-run.py | 2 +-
deps/v8/tools/concatenate-files.py | 2 +-
deps/v8/tools/disasm.py | 2 +-
deps/v8/tools/eval_gc_nvp.py | 2 +-
deps/v8/tools/external-reference-check.py | 2 +-
deps/v8/tools/find-commit-for-patch.py | 2 +-
deps/v8/tools/gc-nvp-to-csv.py | 2 +-
deps/v8/tools/gc-nvp-trace-processor.py | 2 +-
deps/v8/tools/gcmole/download_gcmole_tools.py | 2 +-
deps/v8/tools/gcmole/parallel.py | 2 +-
deps/v8/tools/gcmole/run-gcmole.py | 2 +-
deps/v8/tools/gen-postmortem-metadata.py | 2 +-
deps/v8/tools/generate-builtins-tests.py | 2 +-
.../generate_shim_headers/generate_shim_headers.py | 2 +-
deps/v8/tools/grokdump.py | 2 +-
deps/v8/tools/gyp/v8.gyp | 24 +++++++++++-----------
deps/v8/tools/isolate_driver.py | 2 +-
deps/v8/tools/js2c.py | 2 +-
deps/v8/tools/jsfunfuzz/download_jsfunfuzz.py | 2 +-
deps/v8/tools/jsmin.py | 2 +-
deps/v8/tools/ll_prof.py | 2 +-
deps/v8/tools/mingw-generate-makefiles.sh | 2 +-
deps/v8/tools/nacl-run.py | 2 +-
deps/v8/tools/perf-to-html.py | 2 +-
deps/v8/tools/presubmit.py | 2 +-
deps/v8/tools/process-heap-prof.py | 2 +-
deps/v8/tools/release/auto_push.py | 2 +-
deps/v8/tools/release/auto_roll.py | 2 +-
deps/v8/tools/release/auto_tag.py | 2 +-
deps/v8/tools/release/check_clusterfuzz.py | 2 +-
deps/v8/tools/release/common_includes.py | 2 +-
deps/v8/tools/release/create_release.py | 2 +-
deps/v8/tools/release/git_recipes.py | 2 +-
deps/v8/tools/release/merge_to_branch.py | 2 +-
deps/v8/tools/release/mergeinfo.py | 2 +-
deps/v8/tools/release/push_to_candidates.py | 2 +-
deps/v8/tools/release/releases.py | 2 +-
deps/v8/tools/release/script_test.py | 2 +-
deps/v8/tools/release/search_related_commits.py | 2 +-
deps/v8/tools/release/test_scripts.py | 2 +-
.../tools/release/test_search_related_commits.py | 2 +-
deps/v8/tools/run-deopt-fuzzer.py | 2 +-
deps/v8/tools/run-valgrind.py | 2 +-
deps/v8/tools/run.py | 2 +-
deps/v8/tools/run_perf.py | 2 +-
deps/v8/tools/sanitizers/sancov_formatter.py | 2 +-
deps/v8/tools/sanitizers/sancov_merger.py | 2 +-
deps/v8/tools/sanitizers/sanitize_pcs.py | 2 +-
deps/v8/tools/stats-viewer.py | 2 +-
deps/v8/tools/test-server.py | 2 +-
deps/v8/tools/testrunner/local/pool.py | 2 +-
deps/v8/tools/testrunner/local/pool_unittest.py | 2 +-
deps/v8/tools/testrunner/server/daemon.py | 2 +-
deps/v8/tools/trace-maps-processor.py | 2 +-
deps/v8/tools/try_perf.py | 2 +-
deps/v8/tools/unittests/run_perf_test.py | 2 +-
deps/v8/tools/verify_source_deps.py | 2 +-
.../third_party/jinja2/scripts/jinja2-debug.py | 2 +-
.../third_party/jinja2/scripts/make-release.py | 2 +-
.../third_party/markupsafe/bench/runbench.py | 2 +-
.../generate-inspector-protocol-version | 2 +-
.../platform/v8_inspector/build/rjsmin.py | 2 +-
.../platform/v8_inspector/v8_inspector.gyp | 8 ++++----
node.gyp | 4 ++--
test/gc/node_modules/weak/build/gyp-mac-tool | 2 +-
test/parallel/test-child-process-set-blocking.js | 2 +-
test/pummel/test-child-process-spawn-loop.js | 2 +-
test/pummel/test-exec.js | 2 +-
tools/check-imports.py | 2 +-
tools/configure.d/nodedownload.py | 2 +-
tools/genv8constants.py | 2 +-
tools/gyp/buildbot/buildbot_run.py | 2 +-
tools/gyp/gyp | 2 +-
tools/gyp/gyp_main.py | 2 +-
tools/gyp/gyptest.py | 2 +-
tools/gyp/pylib/gyp/MSVSSettings_test.py | 2 +-
tools/gyp/pylib/gyp/__init__.py | 2 +-
tools/gyp/pylib/gyp/common_test.py | 2 +-
tools/gyp/pylib/gyp/easy_xml_test.py | 2 +-
tools/gyp/pylib/gyp/flock_tool.py | 2 +-
tools/gyp/pylib/gyp/generator/msvs_test.py | 2 +-
tools/gyp/pylib/gyp/generator/ninja.py | 2 +-
tools/gyp/pylib/gyp/generator/ninja_test.py | 2 +-
tools/gyp/pylib/gyp/generator/xcode.py | 2 +-
tools/gyp/pylib/gyp/generator/xcode_test.py | 2 +-
tools/gyp/pylib/gyp/input_test.py | 2 +-
tools/gyp/pylib/gyp/mac_tool.py | 2 +-
tools/gyp/pylib/gyp/win_tool.py | 4 ++--
tools/gyp/samples/samples | 2 +-
tools/gyp/setup.py | 2 +-
tools/gyp/tools/emacs/testdata/media.gyp | 2 +-
tools/gyp/tools/emacs/testdata/media.gyp.fontified | 2 +-
tools/gyp/tools/graphviz.py | 2 +-
tools/gyp/tools/pretty_gyp.py | 2 +-
tools/gyp/tools/pretty_sln.py | 2 +-
tools/gyp/tools/pretty_vcproj.py | 2 +-
tools/gyp_node.py | 2 +-
tools/icu/icu-generic.gyp | 4 ++--
tools/icu/icutrim.py | 2 +-
tools/icu/shrink-icu-src.py | 2 +-
tools/install.py | 2 +-
tools/js2c.py | 2 +-
tools/mkssldef.py | 2 +-
tools/specialize_node_d.py | 2 +-
tools/test.py | 2 +-
154 files changed, 180 insertions(+), 180 deletions(-)
diff --git a/common.gypi b/common.gypi
index 01ab2de..5ff1292 100644
--- a/common.gypi
+++ b/common.gypi
@@ -9,7 +9,7 @@
'library%': 'static_library', # allow override to 'shared_library' for DLL/.so builds
'component%': 'static_library', # NB. these names match with what V8 expects
'msvs_multi_core_compile': '0', # we do enable multicore compiles, but not using the V8 way
- 'python%': 'python',
+ 'python%': 'python2',
'node_shared%': 'false',
'force_dynamic_crt%': 0,
diff --git a/configure b/configure
index 42dac5f..387ebe3 100644
--- a/configure
+++ b/configure
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/python2
import errno
import optparse
diff --git a/deps/cares/build/gcc_version.py b/deps/cares/build/gcc_version.py
index da019e8..b4223af 100644
--- a/deps/cares/build/gcc_version.py
+++ b/deps/cares/build/gcc_version.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
import os
import re
diff --git a/deps/cares/gyp_cares b/deps/cares/gyp_cares
index d1f1640..ecd3f0a 100644
--- a/deps/cares/gyp_cares
+++ b/deps/cares/gyp_cares
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
import glob
import platform
diff --git a/deps/npm/node_modules/node-gyp/gyp/buildbot/buildbot_run.py b/deps/npm/node_modules/node-gyp/gyp/buildbot/buildbot_run.py
index 9a2b71f..d5a75fd 100644
--- a/deps/npm/node_modules/node-gyp/gyp/buildbot/buildbot_run.py
+++ b/deps/npm/node_modules/node-gyp/gyp/buildbot/buildbot_run.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/npm/node_modules/node-gyp/gyp/gyp b/deps/npm/node_modules/node-gyp/gyp/gyp
index 1b8b9bd..7c01529 100644
--- a/deps/npm/node_modules/node-gyp/gyp/gyp
+++ b/deps/npm/node_modules/node-gyp/gyp/gyp
@@ -5,4 +5,4 @@
set -e
base=$(dirname "$0")
-exec python "${base}/gyp_main.py" "$@"
+exec python2 "${base}/gyp_main.py" "$@"
diff --git a/deps/npm/node_modules/node-gyp/gyp/gyp_main.py b/deps/npm/node_modules/node-gyp/gyp/gyp_main.py
index 25a6eba..98314a8 100644
--- a/deps/npm/node_modules/node-gyp/gyp/gyp_main.py
+++ b/deps/npm/node_modules/node-gyp/gyp/gyp_main.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2009 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/deps/npm/node_modules/node-gyp/gyp/gyptest.py b/deps/npm/node_modules/node-gyp/gyp/gyptest.py
index 8e4fc47..2df4d3f 100644
--- a/deps/npm/node_modules/node-gyp/gyp/gyptest.py
+++ b/deps/npm/node_modules/node-gyp/gyp/gyptest.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/MSVSSettings_test.py b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/MSVSSettings_test.py
index bf6ea6b..340fd57 100644
--- a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/MSVSSettings_test.py
+++ b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/MSVSSettings_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/__init__.py b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/__init__.py
index 668f38b..186c94a 100644
--- a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/__init__.py
+++ b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/__init__.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/common_test.py b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/common_test.py
index ad6f9a1..bf0fa40 100644
--- a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/common_test.py
+++ b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/common_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/easy_xml_test.py b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/easy_xml_test.py
index df64354..c8b594f 100644
--- a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/easy_xml_test.py
+++ b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/easy_xml_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2011 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/flock_tool.py b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/flock_tool.py
index b38d866..fdf9785 100644
--- a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/flock_tool.py
+++ b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/flock_tool.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2011 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/msvs_test.py b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/msvs_test.py
index c0b021d..0eb53ea 100644
--- a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/msvs_test.py
+++ b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/msvs_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/ninja.py b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/ninja.py
index 841067e..68ab4ca 100644
--- a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/ninja.py
+++ b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/ninja.py
@@ -1754,7 +1754,7 @@ def _AddWinLinkRules(master_ninja, embed_manifest):
return '%(python)s gyp-win-tool link-with-manifests $arch %(embed)s ' \
'%(out)s "%(ldcmd)s" %(resname)s $mt $rc "$intermediatemanifest" ' \
'$manifests' % {
- 'python': sys.executable,
+ 'python2': sys.executable,
'out': out,
'ldcmd': ldcmd,
'resname': resource_name,
diff --git a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/ninja_test.py b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/ninja_test.py
index 1767b2f..5c75cc3 100644
--- a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/ninja_test.py
+++ b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/ninja_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/xcode.py b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/xcode.py
index 0e3fb93..22dc520 100644
--- a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/xcode.py
+++ b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/xcode.py
@@ -283,7 +283,7 @@ class XcodeProject(object):
command_prefix = ''
if serialize_all_tests:
command_prefix = \
-"""python -c "import fcntl, subprocess, sys
+"""python2 -c "import fcntl, subprocess, sys
file = open('$TMPDIR/GYP_serialize_test_runs', 'a')
fcntl.flock(file.fileno(), fcntl.LOCK_EX)
sys.exit(subprocess.call(sys.argv[1:]))" """
diff --git a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/xcode_test.py b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/xcode_test.py
index 260324a..77a5687 100644
--- a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/xcode_test.py
+++ b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/generator/xcode_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2013 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/input_test.py b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/input_test.py
index 4234fbb..110627e 100644
--- a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/input_test.py
+++ b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/input_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2013 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/mac_tool.py b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/mac_tool.py
index eeeaceb..c83820a 100644
--- a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/mac_tool.py
+++ b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/mac_tool.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/win_tool.py b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/win_tool.py
index bb6f1ea..e3d244a 100644
--- a/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/win_tool.py
+++ b/deps/npm/node_modules/node-gyp/gyp/pylib/gyp/win_tool.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
@@ -144,7 +144,7 @@ class WinTool(object):
# first and only link. We still tell link to generate a manifest, but we
# only use that to assert that our simpler process did not miss anything.
variables = {
- 'python': sys.executable,
+ 'python2': sys.executable,
'arch': arch,
'out': out,
'ldcmd': ldcmd,
diff --git a/deps/npm/node_modules/node-gyp/gyp/samples/samples b/deps/npm/node_modules/node-gyp/gyp/samples/samples
index 804b618..0139666 100644
--- a/deps/npm/node_modules/node-gyp/gyp/samples/samples
+++ b/deps/npm/node_modules/node-gyp/gyp/samples/samples
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python2
# Copyright (c) 2009 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/deps/npm/node_modules/node-gyp/gyp/setup.py b/deps/npm/node_modules/node-gyp/gyp/setup.py
index 75a4255..e4ec8ba 100644
--- a/deps/npm/node_modules/node-gyp/gyp/setup.py
+++ b/deps/npm/node_modules/node-gyp/gyp/setup.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2009 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/deps/npm/node_modules/node-gyp/gyp/tools/emacs/testdata/media.gyp b/deps/npm/node_modules/node-gyp/gyp/tools/emacs/testdata/media.gyp
index 29300fe..c10cdd1 100644
--- a/deps/npm/node_modules/node-gyp/gyp/tools/emacs/testdata/media.gyp
+++ b/deps/npm/node_modules/node-gyp/gyp/tools/emacs/testdata/media.gyp
@@ -987,7 +987,7 @@
'<(SHARED_INTERMEDIATE_DIR)/media/jni/media_player_listener_jni.h',
],
'action': [
- 'python',
+ 'python2',
'<(DEPTH)/base/android/jni_generator/jni_generator.py',
'-o',
'<@(_inputs)',
diff --git a/deps/npm/node_modules/node-gyp/gyp/tools/emacs/testdata/media.gyp.fontified b/deps/npm/node_modules/node-gyp/gyp/tools/emacs/testdata/media.gyp.fontified
index 962b7b2..0ef99fc 100644
--- a/deps/npm/node_modules/node-gyp/gyp/tools/emacs/testdata/media.gyp.fontified
+++ b/deps/npm/node_modules/node-gyp/gyp/tools/emacs/testdata/media.gyp.fontified
@@ -988,7 +988,7 @@
'<(SHARED_INTERMEDIATE_DIR)/media/jni/media_player_listener_jni.h',
],
'action': [
- 'python',
+ 'python2',
'<(DEPTH)/base/android/jni_generator/jni_generator.py',
'-o',
'<@(_inputs)',
diff --git a/deps/npm/node_modules/node-gyp/gyp/tools/graphviz.py b/deps/npm/node_modules/node-gyp/gyp/tools/graphviz.py
index 326ae22..553a101 100644
--- a/deps/npm/node_modules/node-gyp/gyp/tools/graphviz.py
+++ b/deps/npm/node_modules/node-gyp/gyp/tools/graphviz.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2011 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/deps/npm/node_modules/node-gyp/gyp/tools/pretty_gyp.py b/deps/npm/node_modules/node-gyp/gyp/tools/pretty_gyp.py
index c51d358..262a0b3 100644
--- a/deps/npm/node_modules/node-gyp/gyp/tools/pretty_gyp.py
+++ b/deps/npm/node_modules/node-gyp/gyp/tools/pretty_gyp.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/deps/npm/node_modules/node-gyp/gyp/tools/pretty_sln.py b/deps/npm/node_modules/node-gyp/gyp/tools/pretty_sln.py
index ca8cf4a..13aef67 100644
--- a/deps/npm/node_modules/node-gyp/gyp/tools/pretty_sln.py
+++ b/deps/npm/node_modules/node-gyp/gyp/tools/pretty_sln.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/deps/npm/node_modules/node-gyp/gyp/tools/pretty_vcproj.py b/deps/npm/node_modules/node-gyp/gyp/tools/pretty_vcproj.py
index 6099bd7..41530a8 100644
--- a/deps/npm/node_modules/node-gyp/gyp/tools/pretty_vcproj.py
+++ b/deps/npm/node_modules/node-gyp/gyp/tools/pretty_vcproj.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/deps/npm/node_modules/node-gyp/test/test-find-python.js b/deps/npm/node_modules/node-gyp/test/test-find-python.js
index 7f5c394..7c83daa 100644
--- a/deps/npm/node_modules/node-gyp/test/test-find-python.js
+++ b/deps/npm/node_modules/node-gyp/test/test-find-python.js
@@ -7,7 +7,7 @@ var execFile = require('child_process').execFile
test('find python executable', function (t) {
t.plan(4)
- configure.test.findPython('python', function (err, found) {
+ configure.test.findPython('python2', function (err, found) {
t.strictEqual(err, null)
var proc = execFile(found, ['-V'], function (err, stdout, stderr) {
t.strictEqual(err, null)
diff --git a/deps/uv/gyp_uv.py b/deps/uv/gyp_uv.py
index bd37d95..297059b 100644
--- a/deps/uv/gyp_uv.py
+++ b/deps/uv/gyp_uv.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
import os
import platform
diff --git a/deps/v8/DEPS b/deps/v8/DEPS
index 0559523..71aacbc 100644
--- a/deps/v8/DEPS
+++ b/deps/v8/DEPS
@@ -64,7 +64,7 @@ hooks = [
'name': 'landmines',
'pattern': '.',
'action': [
- 'python',
+ 'python2',
'v8/build/landmines.py',
],
},
@@ -106,7 +106,7 @@ hooks = [
'name': 'gcmole',
'pattern': '.',
'action': [
- 'python',
+ 'python2',
'v8/tools/gcmole/download_gcmole_tools.py',
],
},
@@ -114,7 +114,7 @@ hooks = [
'name': 'jsfunfuzz',
'pattern': '.',
'action': [
- 'python',
+ 'python2',
'v8/tools/jsfunfuzz/download_jsfunfuzz.py',
],
},
@@ -190,7 +190,7 @@ hooks = [
# Update the Windows toolchain if necessary.
'name': 'win_toolchain',
'pattern': '.',
- 'action': ['python', 'v8/build/vs_toolchain.py', 'update'],
+ 'action': ['python2', 'v8/build/vs_toolchain.py', 'update'],
},
# Pull binutils for linux, enabled debug fission for faster linking /
# debugging when used with clang on Ubuntu Precise.
@@ -199,7 +199,7 @@ hooks = [
'name': 'binutils',
'pattern': 'v8/third_party/binutils',
'action': [
- 'python',
+ 'python2',
'v8/third_party/binutils/download.py',
],
},
@@ -208,14 +208,14 @@ hooks = [
# Note: This must run before the clang update.
'name': 'gold_plugin',
'pattern': '.',
- 'action': ['python', 'v8/build/download_gold_plugin.py'],
+ 'action': ['python2', 'v8/build/download_gold_plugin.py'],
},
{
# Pull clang if needed or requested via GYP_DEFINES.
# Note: On Win, this should run after win_toolchain, as it may use it.
'name': 'clang',
'pattern': '.',
- 'action': ['python', 'v8/tools/clang/scripts/update.py', '--if-needed'],
+ 'action': ['python2', 'v8/tools/clang/scripts/update.py', '--if-needed'],
},
{
# A change to a .gyp, .gypi, or to GYP itself should run the generator.
diff --git a/deps/v8/Makefile b/deps/v8/Makefile
index a0c08a6..66af786 100644
--- a/deps/v8/Makefile
+++ b/deps/v8/Makefile
@@ -311,7 +311,7 @@ $(ARCHES): $(addprefix $$@.,$(DEFAULT_MODES))
$(BUILDS): $(OUTDIR)/Makefile.$$@
@$(MAKE) -C "$(OUTDIR)" -f Makefile.$@ \
BUILDTYPE=$(shell echo $(subst .,,$(suffix $@)) | \
- python -c "print \
+ python2 -c "print \
raw_input().replace('opt', '').capitalize()") \
builddir="$(shell pwd)/$(OUTDIR)/$@"
diff --git a/deps/v8/Makefile.android b/deps/v8/Makefile.android
index c49cb85..d1c9699 100644
--- a/deps/v8/Makefile.android
+++ b/deps/v8/Makefile.android
@@ -58,7 +58,7 @@ DEFINES += OS=android
$(ANDROID_BUILDS): $(OUTDIR)/Makefile.$$@
@$(MAKE) -C "$(OUTDIR)" -f Makefile.$@ \
BUILDTYPE=$(shell echo $(subst .,,$(suffix $@)) | \
- python -c "print raw_input().capitalize()") \
+ python2 -c "print raw_input().capitalize()") \
builddir="$(shell pwd)/$(OUTDIR)/$@"
# Android GYP file generation targets.
diff --git a/deps/v8/Makefile.nacl b/deps/v8/Makefile.nacl
index 3459c42..bb7fc31 100644
--- a/deps/v8/Makefile.nacl
+++ b/deps/v8/Makefile.nacl
@@ -80,7 +80,7 @@ $(NACL_BUILDS): $(NACL_MAKEFILES)
LD="$(NACL_TOOLCHAIN)/bin/pnacl-ld" \
LINK=${NACL_LINK} \
BUILDTYPE=$(shell echo $(subst .,,$(suffix $@)) | \
- python -c "print raw_input().capitalize()") \
+ python2 -c "print raw_input().capitalize()") \
builddir="$(shell pwd)/$(OUTDIR)/$@"
# NACL GYP file generation targets.
diff --git a/deps/v8/build/coverage_wrapper.py b/deps/v8/build/coverage_wrapper.py
index 5b365d8..3fd6cfa 100644
--- a/deps/v8/build/coverage_wrapper.py
+++ b/deps/v8/build/coverage_wrapper.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2016 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/build/detect_v8_host_arch.py b/deps/v8/build/detect_v8_host_arch.py
index 89e8286..87ad379 100644
--- a/deps/v8/build/detect_v8_host_arch.py
+++ b/deps/v8/build/detect_v8_host_arch.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
diff --git a/deps/v8/build/download_gold_plugin.py b/deps/v8/build/download_gold_plugin.py
index b8131fd..81e04e1 100644
--- a/deps/v8/build/download_gold_plugin.py
+++ b/deps/v8/build/download_gold_plugin.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2015 the V8 project authors. All rights reserved.
# Copyright 2015 The Chromium Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
@@ -70,7 +70,7 @@ def main():
# (currently aborts with exit code 1,
# https://github.com/GoogleCloudPlatform/gsutil/issues/289) or change the
# stdin->stderr redirect in update.py to do something else (crbug.com/494442).
- subprocess.check_call(['python', GSUTIL_PATH,
+ subprocess.check_call(['python2', GSUTIL_PATH,
'cp', remote_path, targz_name],
stderr=open('/dev/null', 'w'))
subprocess.check_call(['tar', 'xzf', targz_name])
diff --git a/deps/v8/build/get_landmines.py b/deps/v8/build/get_landmines.py
index 2bbf7a6..f1b7e9d 100644
--- a/deps/v8/build/get_landmines.py
+++ b/deps/v8/build/get_landmines.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/build/gyp_v8 b/deps/v8/build/gyp_v8
index 8813f2c..e8ea57c 100644
--- a/deps/v8/build/gyp_v8
+++ b/deps/v8/build/gyp_v8
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff --git a/deps/v8/build/has_valgrind.py b/deps/v8/build/has_valgrind.py
index 83a848d..cfb8605 100644
--- a/deps/v8/build/has_valgrind.py
+++ b/deps/v8/build/has_valgrind.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2016 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/build/isolate.gypi b/deps/v8/build/isolate.gypi
index 4cfbbfd..5698bde 100644
--- a/deps/v8/build/isolate.gypi
+++ b/deps/v8/build/isolate.gypi
@@ -52,7 +52,7 @@
'<(PRODUCT_DIR)/<(RULE_INPUT_ROOT).isolated',
],
'action': [
- 'python',
+ 'python2',
'<(DEPTH)/tools/isolate_driver.py',
'<(test_isolation_mode)',
'--isolated', '<(PRODUCT_DIR)/<(RULE_INPUT_ROOT).isolated',
diff --git a/deps/v8/build/landmines.py b/deps/v8/build/landmines.py
index 97c6390..215d8c0 100644
--- a/deps/v8/build/landmines.py
+++ b/deps/v8/build/landmines.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/build/shim_headers.gypi b/deps/v8/build/shim_headers.gypi
index 940211c..7e21773 100644
--- a/deps/v8/build/shim_headers.gypi
+++ b/deps/v8/build/shim_headers.gypi
@@ -62,7 +62,7 @@
'outputs': [
'<!@pymod_do_main(generate_shim_headers <@(generator_args) --outputs)',
],
- 'action': ['python',
+ 'action': ['python2',
'<(generator_path)',
'<@(generator_args)',
'--generate',
diff --git a/deps/v8/build/standalone.gypi b/deps/v8/build/standalone.gypi
index 6c88409..3507514 100644
--- a/deps/v8/build/standalone.gypi
+++ b/deps/v8/build/standalone.gypi
@@ -66,7 +66,7 @@
},
'host_arch%': '<(host_arch)',
'target_arch%': '<(host_arch)',
- 'base_dir%': '<!(cd <(DEPTH) && python -c "import os; print os.getcwd()")',
+ 'base_dir%': '<!(cd <(DEPTH) && python2 -c "import os; print os.getcwd()")',
# Instrument for code coverage and use coverage wrapper to exclude some
# files. Uses gcov if clang=0 is set explicitly. Otherwise,
diff --git a/deps/v8/build/toolchain.gypi b/deps/v8/build/toolchain.gypi
index 519779e..8da8c53 100644
--- a/deps/v8/build/toolchain.gypi
+++ b/deps/v8/build/toolchain.gypi
@@ -38,7 +38,7 @@
'ubsan%': 0,
'ubsan_vptr%': 0,
'v8_target_arch%': '<(target_arch)',
- 'v8_host_byteorder%': '<!(python -c "import sys; print sys.byteorder")',
+ 'v8_host_byteorder%': '<!(python2 -c "import sys; print sys.byteorder")',
'force_dynamic_crt%': 0,
# Native Client builds currently use the V8 ARM JIT and
# arm/simulator-arm.cc to defer the significant effort required
diff --git a/deps/v8/build/vs_toolchain.py b/deps/v8/build/vs_toolchain.py
index 95fbcf4..6f9d68c 100644
--- a/deps/v8/build/vs_toolchain.py
+++ b/deps/v8/build/vs_toolchain.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2015 the V8 project authors. All rights reserved.
# Copyright 2014 The Chromium Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/deps/v8/src/d8.gyp b/deps/v8/src/d8.gyp
index f249a78..7499d6d 100644
--- a/deps/v8/src/d8.gyp
+++ b/deps/v8/src/d8.gyp
@@ -130,7 +130,7 @@
'<(SHARED_INTERMEDIATE_DIR)/d8-js.cc',
],
'action': [
- 'python',
+ 'python2',
'../tools/js2c.py',
'<@(_outputs)',
'D8',
diff --git a/deps/v8/tools/android-run.py b/deps/v8/tools/android-run.py
index dc13598..edf2ae1 100644
--- a/deps/v8/tools/android-run.py
+++ b/deps/v8/tools/android-run.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff --git a/deps/v8/tools/concatenate-files.py b/deps/v8/tools/concatenate-files.py
index 86bdf56..1ad4bd0 100644
--- a/deps/v8/tools/concatenate-files.py
+++ b/deps/v8/tools/concatenate-files.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2014 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff --git a/deps/v8/tools/disasm.py b/deps/v8/tools/disasm.py
index f409cb0..dec96b1 100644
--- a/deps/v8/tools/disasm.py
+++ b/deps/v8/tools/disasm.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2011 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff --git a/deps/v8/tools/eval_gc_nvp.py b/deps/v8/tools/eval_gc_nvp.py
index fcb6d8b..d4eb12f 100644
--- a/deps/v8/tools/eval_gc_nvp.py
+++ b/deps/v8/tools/eval_gc_nvp.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2015 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/deps/v8/tools/external-reference-check.py b/deps/v8/tools/external-reference-check.py
index be01dec..5924ae7 100644
--- a/deps/v8/tools/external-reference-check.py
+++ b/deps/v8/tools/external-reference-check.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/find-commit-for-patch.py b/deps/v8/tools/find-commit-for-patch.py
index 657826c..a87b721 100644
--- a/deps/v8/tools/find-commit-for-patch.py
+++ b/deps/v8/tools/find-commit-for-patch.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/gc-nvp-to-csv.py b/deps/v8/tools/gc-nvp-to-csv.py
index 26ed8e1..616e2d0 100644
--- a/deps/v8/tools/gc-nvp-to-csv.py
+++ b/deps/v8/tools/gc-nvp-to-csv.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2015 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/deps/v8/tools/gc-nvp-trace-processor.py b/deps/v8/tools/gc-nvp-trace-processor.py
index 21526ae..1bc3426 100644
--- a/deps/v8/tools/gc-nvp-trace-processor.py
+++ b/deps/v8/tools/gc-nvp-trace-processor.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2010 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff --git a/deps/v8/tools/gcmole/download_gcmole_tools.py b/deps/v8/tools/gcmole/download_gcmole_tools.py
index 7183d28..ad0a841 100644
--- a/deps/v8/tools/gcmole/download_gcmole_tools.py
+++ b/deps/v8/tools/gcmole/download_gcmole_tools.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2016 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/gcmole/parallel.py b/deps/v8/tools/gcmole/parallel.py
index 0c045f4..505ddab 100644
--- a/deps/v8/tools/gcmole/parallel.py
+++ b/deps/v8/tools/gcmole/parallel.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2015 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/gcmole/run-gcmole.py b/deps/v8/tools/gcmole/run-gcmole.py
index a1e4f24..aa23cfd 100644
--- a/deps/v8/tools/gcmole/run-gcmole.py
+++ b/deps/v8/tools/gcmole/run-gcmole.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2016 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/gen-postmortem-metadata.py b/deps/v8/tools/gen-postmortem-metadata.py
index a0afc06..dcdaf7a 100644
--- a/deps/v8/tools/gen-postmortem-metadata.py
+++ b/deps/v8/tools/gen-postmortem-metadata.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
diff --git a/deps/v8/tools/generate-builtins-tests.py b/deps/v8/tools/generate-builtins-tests.py
index 4e6961d..00dea5a 100644
--- a/deps/v8/tools/generate-builtins-tests.py
+++ b/deps/v8/tools/generate-builtins-tests.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/generate_shim_headers/generate_shim_headers.py b/deps/v8/tools/generate_shim_headers/generate_shim_headers.py
index d0e6d06..127e768 100644
--- a/deps/v8/tools/generate_shim_headers/generate_shim_headers.py
+++ b/deps/v8/tools/generate_shim_headers/generate_shim_headers.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2013 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff --git a/deps/v8/tools/grokdump.py b/deps/v8/tools/grokdump.py
index ab8f326..bf66e39 100644
--- a/deps/v8/tools/grokdump.py
+++ b/deps/v8/tools/grokdump.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff --git a/deps/v8/tools/gyp/v8.gyp b/deps/v8/tools/gyp/v8.gyp
index b09fd1f..e1ba0b1 100644
--- a/deps/v8/tools/gyp/v8.gyp
+++ b/deps/v8/tools/gyp/v8.gyp
@@ -1985,14 +1985,14 @@
'<(PRODUCT_DIR)/natives_blob_host.bin',
],
'action': [
- 'python', '<@(_inputs)', '<(PRODUCT_DIR)/natives_blob_host.bin'
+ 'python2', '<@(_inputs)', '<(PRODUCT_DIR)/natives_blob_host.bin'
],
}, {
'outputs': [
'<(PRODUCT_DIR)/natives_blob.bin',
],
'action': [
- 'python', '<@(_inputs)', '<(PRODUCT_DIR)/natives_blob.bin'
+ 'python2', '<@(_inputs)', '<(PRODUCT_DIR)/natives_blob.bin'
],
}],
],
@@ -2001,7 +2001,7 @@
'<(PRODUCT_DIR)/natives_blob.bin',
],
'action': [
- 'python', '<@(_inputs)', '<(PRODUCT_DIR)/natives_blob.bin'
+ 'python2', '<@(_inputs)', '<(PRODUCT_DIR)/natives_blob.bin'
],
}],
],
@@ -2098,7 +2098,7 @@
],
'outputs': ['<(SHARED_INTERMEDIATE_DIR)/libraries.cc'],
'action': [
- 'python',
+ 'python2',
'../../tools/js2c.py',
'<(SHARED_INTERMEDIATE_DIR)/libraries.cc',
'CORE',
@@ -2115,7 +2115,7 @@
],
'outputs': ['<@(libraries_bin_file)'],
'action': [
- 'python',
+ 'python2',
'../../tools/js2c.py',
'<(SHARED_INTERMEDIATE_DIR)/libraries.cc',
'CORE',
@@ -2133,7 +2133,7 @@
],
'outputs': ['<(SHARED_INTERMEDIATE_DIR)/experimental-libraries.cc'],
'action': [
- 'python',
+ 'python2',
'../../tools/js2c.py',
'<(SHARED_INTERMEDIATE_DIR)/experimental-libraries.cc',
'EXPERIMENTAL',
@@ -2148,7 +2148,7 @@
],
'outputs': ['<@(libraries_experimental_bin_file)'],
'action': [
- 'python',
+ 'python2',
'../../tools/js2c.py',
'<(SHARED_INTERMEDIATE_DIR)/experimental-libraries.cc',
'EXPERIMENTAL',
@@ -2165,7 +2165,7 @@
],
'outputs': ['<(SHARED_INTERMEDIATE_DIR)/extras-libraries.cc'],
'action': [
- 'python',
+ 'python2',
'../../tools/js2c.py',
'<(SHARED_INTERMEDIATE_DIR)/extras-libraries.cc',
'EXTRAS',
@@ -2180,7 +2180,7 @@
],
'outputs': ['<@(libraries_extras_bin_file)'],
'action': [
- 'python',
+ 'python2',
'../../tools/js2c.py',
'<(SHARED_INTERMEDIATE_DIR)/extras-libraries.cc',
'EXTRAS',
@@ -2199,7 +2199,7 @@
'<(SHARED_INTERMEDIATE_DIR)/experimental-extras-libraries.cc',
],
'action': [
- 'python',
+ 'python2',
'../../tools/js2c.py',
'<(SHARED_INTERMEDIATE_DIR)/experimental-extras-libraries.cc',
'EXPERIMENTAL_EXTRAS',
@@ -2214,7 +2214,7 @@
],
'outputs': ['<@(libraries_experimental_extras_bin_file)'],
'action': [
- 'python',
+ 'python2',
'../../tools/js2c.py',
'<(SHARED_INTERMEDIATE_DIR)/experimental-extras-libraries.cc',
'EXPERIMENTAL_EXTRAS',
@@ -2245,7 +2245,7 @@
'<(SHARED_INTERMEDIATE_DIR)/debug-support.cc',
],
'action': [
- 'python',
+ 'python2',
'../../tools/gen-postmortem-metadata.py',
'<@(_outputs)',
'<@(heapobject_files)'
diff --git a/deps/v8/tools/isolate_driver.py b/deps/v8/tools/isolate_driver.py
index d1b39b0..d38f73f 100644
--- a/deps/v8/tools/isolate_driver.py
+++ b/deps/v8/tools/isolate_driver.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2015 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/js2c.py b/deps/v8/tools/js2c.py
index d915133..8fb160d 100644
--- a/deps/v8/tools/js2c.py
+++ b/deps/v8/tools/js2c.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff --git a/deps/v8/tools/jsfunfuzz/download_jsfunfuzz.py b/deps/v8/tools/jsfunfuzz/download_jsfunfuzz.py
index 19eff02..ad19b71 100644
--- a/deps/v8/tools/jsfunfuzz/download_jsfunfuzz.py
+++ b/deps/v8/tools/jsfunfuzz/download_jsfunfuzz.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2016 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/jsmin.py b/deps/v8/tools/jsmin.py
index 236f511..26f1976 100644
--- a/deps/v8/tools/jsmin.py
+++ b/deps/v8/tools/jsmin.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python2.4
+#!/usr/bin/python2
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff --git a/deps/v8/tools/ll_prof.py b/deps/v8/tools/ll_prof.py
index ca2cb00..811b437 100644
--- a/deps/v8/tools/ll_prof.py
+++ b/deps/v8/tools/ll_prof.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff --git a/deps/v8/tools/mingw-generate-makefiles.sh b/deps/v8/tools/mingw-generate-makefiles.sh
index 32af52d..241948d 100644
--- a/deps/v8/tools/mingw-generate-makefiles.sh
+++ b/deps/v8/tools/mingw-generate-makefiles.sh
@@ -28,7 +28,7 @@
# Monkey-patch GYP.
cat > build/gyp/gyp.mingw << EOF
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2009 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/deps/v8/tools/nacl-run.py b/deps/v8/tools/nacl-run.py
index 32055fe..edcc08f 100644
--- a/deps/v8/tools/nacl-run.py
+++ b/deps/v8/tools/nacl-run.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2013 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff --git a/deps/v8/tools/perf-to-html.py b/deps/v8/tools/perf-to-html.py
index 63faeb1..3a68c60 100644
--- a/deps/v8/tools/perf-to-html.py
+++ b/deps/v8/tools/perf-to-html.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2015 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/presubmit.py b/deps/v8/tools/presubmit.py
index dd3533b..5fbc677 100644
--- a/deps/v8/tools/presubmit.py
+++ b/deps/v8/tools/presubmit.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff --git a/deps/v8/tools/process-heap-prof.py b/deps/v8/tools/process-heap-prof.py
index a26cbf1..c7a4e6e 100644
--- a/deps/v8/tools/process-heap-prof.py
+++ b/deps/v8/tools/process-heap-prof.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2009 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff --git a/deps/v8/tools/release/auto_push.py b/deps/v8/tools/release/auto_push.py
index ca9e5e8..5b91dec 100644
--- a/deps/v8/tools/release/auto_push.py
+++ b/deps/v8/tools/release/auto_push.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2013 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
diff --git a/deps/v8/tools/release/auto_roll.py b/deps/v8/tools/release/auto_roll.py
index b71cac5..891b34a 100644
--- a/deps/v8/tools/release/auto_roll.py
+++ b/deps/v8/tools/release/auto_roll.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/release/auto_tag.py b/deps/v8/tools/release/auto_tag.py
index a52a028..b71c19c 100644
--- a/deps/v8/tools/release/auto_tag.py
+++ b/deps/v8/tools/release/auto_tag.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/release/check_clusterfuzz.py b/deps/v8/tools/release/check_clusterfuzz.py
index cd73051..ad4297d 100644
--- a/deps/v8/tools/release/check_clusterfuzz.py
+++ b/deps/v8/tools/release/check_clusterfuzz.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/release/common_includes.py b/deps/v8/tools/release/common_includes.py
index 5c03236..59c390e 100644
--- a/deps/v8/tools/release/common_includes.py
+++ b/deps/v8/tools/release/common_includes.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2013 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
diff --git a/deps/v8/tools/release/create_release.py b/deps/v8/tools/release/create_release.py
index 7477ea1..8915f7f 100644
--- a/deps/v8/tools/release/create_release.py
+++ b/deps/v8/tools/release/create_release.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2015 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/release/git_recipes.py b/deps/v8/tools/release/git_recipes.py
index 89fd7c9..03bb62e 100644
--- a/deps/v8/tools/release/git_recipes.py
+++ b/deps/v8/tools/release/git_recipes.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
diff --git a/deps/v8/tools/release/merge_to_branch.py b/deps/v8/tools/release/merge_to_branch.py
index 699fe1b..ea72b4a 100644
--- a/deps/v8/tools/release/merge_to_branch.py
+++ b/deps/v8/tools/release/merge_to_branch.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
diff --git a/deps/v8/tools/release/mergeinfo.py b/deps/v8/tools/release/mergeinfo.py
index 7f8b9cb..0035a83 100644
--- a/deps/v8/tools/release/mergeinfo.py
+++ b/deps/v8/tools/release/mergeinfo.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2015 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/release/push_to_candidates.py b/deps/v8/tools/release/push_to_candidates.py
index 750794e..299771a 100644
--- a/deps/v8/tools/release/push_to_candidates.py
+++ b/deps/v8/tools/release/push_to_candidates.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2013 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
diff --git a/deps/v8/tools/release/releases.py b/deps/v8/tools/release/releases.py
index 7b659cc..61b2eec 100644
--- a/deps/v8/tools/release/releases.py
+++ b/deps/v8/tools/release/releases.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/release/script_test.py b/deps/v8/tools/release/script_test.py
index cbb2134..3d2adcf 100644
--- a/deps/v8/tools/release/script_test.py
+++ b/deps/v8/tools/release/script_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
diff --git a/deps/v8/tools/release/search_related_commits.py b/deps/v8/tools/release/search_related_commits.py
index d27aa56..bf016d1 100644
--- a/deps/v8/tools/release/search_related_commits.py
+++ b/deps/v8/tools/release/search_related_commits.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2015 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/release/test_scripts.py b/deps/v8/tools/release/test_scripts.py
index 05457c9..9844530 100644
--- a/deps/v8/tools/release/test_scripts.py
+++ b/deps/v8/tools/release/test_scripts.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2013 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
diff --git a/deps/v8/tools/release/test_search_related_commits.py b/deps/v8/tools/release/test_search_related_commits.py
index cf61236..3eca10e 100644
--- a/deps/v8/tools/release/test_search_related_commits.py
+++ b/deps/v8/tools/release/test_search_related_commits.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2015 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/run-deopt-fuzzer.py b/deps/v8/tools/run-deopt-fuzzer.py
index 970aa8e..e93e73d 100644
--- a/deps/v8/tools/run-deopt-fuzzer.py
+++ b/deps/v8/tools/run-deopt-fuzzer.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff --git a/deps/v8/tools/run-valgrind.py b/deps/v8/tools/run-valgrind.py
index e3f84f5..de78300 100644
--- a/deps/v8/tools/run-valgrind.py
+++ b/deps/v8/tools/run-valgrind.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2009 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff --git a/deps/v8/tools/run.py b/deps/v8/tools/run.py
index 5a656e1..c6fc589 100644
--- a/deps/v8/tools/run.py
+++ b/deps/v8/tools/run.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/run_perf.py b/deps/v8/tools/run_perf.py
index db4245f..aa48704 100644
--- a/deps/v8/tools/run_perf.py
+++ b/deps/v8/tools/run_perf.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/sanitizers/sancov_formatter.py b/deps/v8/tools/sanitizers/sancov_formatter.py
index 4f3ea9e..5845fa1 100644
--- a/deps/v8/tools/sanitizers/sancov_formatter.py
+++ b/deps/v8/tools/sanitizers/sancov_formatter.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2016 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/sanitizers/sancov_merger.py b/deps/v8/tools/sanitizers/sancov_merger.py
index a4cfec1..347401e 100644
--- a/deps/v8/tools/sanitizers/sancov_merger.py
+++ b/deps/v8/tools/sanitizers/sancov_merger.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2016 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/sanitizers/sanitize_pcs.py b/deps/v8/tools/sanitizers/sanitize_pcs.py
index 47f2715..df58ff6 100644
--- a/deps/v8/tools/sanitizers/sanitize_pcs.py
+++ b/deps/v8/tools/sanitizers/sanitize_pcs.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2016 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/stats-viewer.py b/deps/v8/tools/stats-viewer.py
index ab8e287..702151d 100644
--- a/deps/v8/tools/stats-viewer.py
+++ b/deps/v8/tools/stats-viewer.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2008 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff --git a/deps/v8/tools/test-server.py b/deps/v8/tools/test-server.py
index ab927de..a94b61a 100644
--- a/deps/v8/tools/test-server.py
+++ b/deps/v8/tools/test-server.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2012 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff --git a/deps/v8/tools/testrunner/local/pool.py b/deps/v8/tools/testrunner/local/pool.py
index 99996ee..4682378 100644
--- a/deps/v8/tools/testrunner/local/pool.py
+++ b/deps/v8/tools/testrunner/local/pool.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/testrunner/local/pool_unittest.py b/deps/v8/tools/testrunner/local/pool_unittest.py
index 335d20a..7e89d8b 100644
--- a/deps/v8/tools/testrunner/local/pool_unittest.py
+++ b/deps/v8/tools/testrunner/local/pool_unittest.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/testrunner/server/daemon.py b/deps/v8/tools/testrunner/server/daemon.py
index baa66fb..26a58c8 100644
--- a/deps/v8/tools/testrunner/server/daemon.py
+++ b/deps/v8/tools/testrunner/server/daemon.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# This code has been written by Sander Marechal and published at:
# http://www.jejik.com/articles/2007/02/a_simple_unix_linux_daemon_in_python/
diff --git a/deps/v8/tools/trace-maps-processor.py b/deps/v8/tools/trace-maps-processor.py
index bf8c8a8..3397998 100644
--- a/deps/v8/tools/trace-maps-processor.py
+++ b/deps/v8/tools/trace-maps-processor.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/try_perf.py b/deps/v8/tools/try_perf.py
index fbd4036..0948dcf 100644
--- a/deps/v8/tools/try_perf.py
+++ b/deps/v8/tools/try_perf.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/unittests/run_perf_test.py b/deps/v8/tools/unittests/run_perf_test.py
index 1a4d738..b0a576d 100644
--- a/deps/v8/tools/unittests/run_perf_test.py
+++ b/deps/v8/tools/unittests/run_perf_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2014 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8/tools/verify_source_deps.py b/deps/v8/tools/verify_source_deps.py
index 50caace..7120d64 100644
--- a/deps/v8/tools/verify_source_deps.py
+++ b/deps/v8/tools/verify_source_deps.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2015 the V8 project authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/deps/v8_inspector/third_party/jinja2/scripts/jinja2-debug.py b/deps/v8_inspector/third_party/jinja2/scripts/jinja2-debug.py
index d052adc..bb8748f 100644
--- a/deps/v8_inspector/third_party/jinja2/scripts/jinja2-debug.py
+++ b/deps/v8_inspector/third_party/jinja2/scripts/jinja2-debug.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Jinja2 Debug Interface
diff --git a/deps/v8_inspector/third_party/jinja2/scripts/make-release.py b/deps/v8_inspector/third_party/jinja2/scripts/make-release.py
index 6fd98fe..b160c4b 100644
--- a/deps/v8_inspector/third_party/jinja2/scripts/make-release.py
+++ b/deps/v8_inspector/third_party/jinja2/scripts/make-release.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
make-release
diff --git a/deps/v8_inspector/third_party/markupsafe/bench/runbench.py b/deps/v8_inspector/third_party/markupsafe/bench/runbench.py
index 2ebdc53..2e66366 100644
--- a/deps/v8_inspector/third_party/markupsafe/bench/runbench.py
+++ b/deps/v8_inspector/third_party/markupsafe/bench/runbench.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
"""
Runs the benchmarks
"""
diff --git a/deps/v8_inspector/third_party/v8_inspector/platform/inspector_protocol/generate-inspector-protocol-version b/deps/v8_inspector/third_party/v8_inspector/platform/inspector_protocol/generate-inspector-protocol-version
index 0c01e16..e6e4818 100644
--- a/deps/v8_inspector/third_party/v8_inspector/platform/inspector_protocol/generate-inspector-protocol-version
+++ b/deps/v8_inspector/third_party/v8_inspector/platform/inspector_protocol/generate-inspector-protocol-version
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2011 Google Inc. All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
diff --git a/deps/v8_inspector/third_party/v8_inspector/platform/v8_inspector/build/rjsmin.py b/deps/v8_inspector/third_party/v8_inspector/platform/v8_inspector/build/rjsmin.py
index 8357a6d..d8a0739 100644
--- a/deps/v8_inspector/third_party/v8_inspector/platform/v8_inspector/build/rjsmin.py
+++ b/deps/v8_inspector/third_party/v8_inspector/platform/v8_inspector/build/rjsmin.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2011 - 2013
# Andr\xe9 Malo or his licensors, as applicable
diff --git a/deps/v8_inspector/third_party/v8_inspector/platform/v8_inspector/v8_inspector.gyp b/deps/v8_inspector/third_party/v8_inspector/platform/v8_inspector/v8_inspector.gyp
index ebfc91a..224bf74 100644
--- a/deps/v8_inspector/third_party/v8_inspector/platform/v8_inspector/v8_inspector.gyp
+++ b/deps/v8_inspector/third_party/v8_inspector/platform/v8_inspector/v8_inspector.gyp
@@ -20,7 +20,7 @@
],
'outputs': [ '<(SHARED_INTERMEDIATE_DIR)/blink/platform/v8_inspector/InjectedScriptSource.h', ],
'action': [
- 'python', 'build/xxd.py', 'InjectedScriptSource_js', 'InjectedScriptSource.js', '<@(_outputs)'
+ 'python2', 'build/xxd.py', 'InjectedScriptSource_js', 'InjectedScriptSource.js', '<@(_outputs)'
],
},
],
@@ -40,7 +40,7 @@
],
'outputs': [ '<(SHARED_INTERMEDIATE_DIR)/blink/platform/v8_inspector/DebuggerScript.h', ],
'action': [
- 'python', 'build/xxd.py', 'DebuggerScript_js', 'DebuggerScript.js', '<@(_outputs)'
+ 'python2', 'build/xxd.py', 'DebuggerScript_js', 'DebuggerScript.js', '<@(_outputs)'
],
},
],
@@ -99,7 +99,7 @@
'<(blink_platform_output_dir)/v8_inspector/public/protocol/Debugger.h',
],
'action': [
- 'python',
+ 'python2',
'../inspector_protocol/CodeGenerator.py',
'--protocol', 'js_protocol.json',
'--string_type', 'String16',
@@ -128,7 +128,7 @@
'<(blink_platform_output_dir)/v8_inspector/protocol.json',
],
'action': [
- 'python',
+ 'python2',
'../inspector_protocol/generate-inspector-protocol-version',
'--o',
'<@(_outputs)',
diff --git a/node.gyp b/node.gyp
index 0f263d1..1b5a23f 100644
--- a/node.gyp
+++ b/node.gyp
@@ -593,7 +593,7 @@
],
'outputs': ['<(SHARED_INTERMEDIATE_DIR)/openssl.def'],
'action': [
- 'python',
+ 'python2',
'tools/mkssldef.py',
'<@(mkssldef_flags)',
'-o',
@@ -676,7 +676,7 @@
}]
],
'action': [
- 'python',
+ 'python2',
'tools/js2c.py',
'<@(_outputs)',
'<@(_inputs)',
diff --git a/test/gc/node_modules/weak/build/gyp-mac-tool b/test/gc/node_modules/weak/build/gyp-mac-tool
index 8ef02b0..b93d9c9 100644
--- a/test/gc/node_modules/weak/build/gyp-mac-tool
+++ b/test/gc/node_modules/weak/build/gyp-mac-tool
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Generated by gyp. Do not edit.
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/test/parallel/test-child-process-set-blocking.js b/test/parallel/test-child-process-set-blocking.js
index fb0b11f..ea2cd11 100644
--- a/test/parallel/test-child-process-set-blocking.js
+++ b/test/parallel/test-child-process-set-blocking.js
@@ -5,7 +5,7 @@ var ch = require('child_process');
var SIZE = 100000;
-var cp = ch.spawn('python', ['-c', 'print ' + SIZE + ' * "C"'], {
+var cp = ch.spawn('python2', ['-c', 'print ' + SIZE + ' * "C"'], {
stdio: 'inherit'
});
diff --git a/test/pummel/test-child-process-spawn-loop.js b/test/pummel/test-child-process-spawn-loop.js
index 7e686ca..6051c6a 100644
--- a/test/pummel/test-child-process-spawn-loop.js
+++ b/test/pummel/test-child-process-spawn-loop.js
@@ -9,7 +9,7 @@ var N = 40;
var finished = false;
function doSpawn(i) {
- var child = spawn('python', ['-c', 'print ' + SIZE + ' * "C"']);
+ var child = spawn('python2', ['-c', 'print ' + SIZE + ' * "C"']);
var count = 0;
child.stdout.setEncoding('ascii');
diff --git a/test/pummel/test-exec.js b/test/pummel/test-exec.js
index 6f6e151..ae6521c 100644
--- a/test/pummel/test-exec.js
+++ b/test/pummel/test-exec.js
@@ -92,7 +92,7 @@ function killMeTwiceCallback(err, stdout, stderr) {
}
-exec('python -c "print 200000*\'C\'"', {maxBuffer: 1000},
+exec('python2 -c "print 200000*\'C\'"', {maxBuffer: 1000},
function(err, stdout, stderr) {
assert.ok(err);
assert.ok(/maxBuffer/.test(err.message));
diff --git a/tools/check-imports.py b/tools/check-imports.py
index b71b4a9..b32d4c7 100644
--- a/tools/check-imports.py
+++ b/tools/check-imports.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
from __future__ import print_function
import glob
diff --git a/tools/configure.d/nodedownload.py b/tools/configure.d/nodedownload.py
index 5cf8e0d..e9576d2 100644
--- a/tools/configure.d/nodedownload.py
+++ b/tools/configure.d/nodedownload.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Moved some utilities here from ../../configure
import urllib
diff --git a/tools/genv8constants.py b/tools/genv8constants.py
index 45b4ae3..f2542a9 100644
--- a/tools/genv8constants.py
+++ b/tools/genv8constants.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# genv8constants.py output_file libv8_base.a
diff --git a/tools/gyp/buildbot/buildbot_run.py b/tools/gyp/buildbot/buildbot_run.py
index 9a2b71f..d5a75fd 100644
--- a/tools/gyp/buildbot/buildbot_run.py
+++ b/tools/gyp/buildbot/buildbot_run.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/tools/gyp/gyp b/tools/gyp/gyp
index 1b8b9bd..7c01529 100644
--- a/tools/gyp/gyp
+++ b/tools/gyp/gyp
@@ -5,4 +5,4 @@
set -e
base=$(dirname "$0")
-exec python "${base}/gyp_main.py" "$@"
+exec python2 "${base}/gyp_main.py" "$@"
diff --git a/tools/gyp/gyp_main.py b/tools/gyp/gyp_main.py
index 25a6eba..98314a8 100644
--- a/tools/gyp/gyp_main.py
+++ b/tools/gyp/gyp_main.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2009 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/tools/gyp/gyptest.py b/tools/gyp/gyptest.py
index 8e4fc47..2df4d3f 100644
--- a/tools/gyp/gyptest.py
+++ b/tools/gyp/gyptest.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/tools/gyp/pylib/gyp/MSVSSettings_test.py b/tools/gyp/pylib/gyp/MSVSSettings_test.py
index bf6ea6b..340fd57 100644
--- a/tools/gyp/pylib/gyp/MSVSSettings_test.py
+++ b/tools/gyp/pylib/gyp/MSVSSettings_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/tools/gyp/pylib/gyp/__init__.py b/tools/gyp/pylib/gyp/__init__.py
index 668f38b..186c94a 100644
--- a/tools/gyp/pylib/gyp/__init__.py
+++ b/tools/gyp/pylib/gyp/__init__.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/tools/gyp/pylib/gyp/common_test.py b/tools/gyp/pylib/gyp/common_test.py
index ad6f9a1..bf0fa40 100644
--- a/tools/gyp/pylib/gyp/common_test.py
+++ b/tools/gyp/pylib/gyp/common_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/tools/gyp/pylib/gyp/easy_xml_test.py b/tools/gyp/pylib/gyp/easy_xml_test.py
index df64354..c8b594f 100644
--- a/tools/gyp/pylib/gyp/easy_xml_test.py
+++ b/tools/gyp/pylib/gyp/easy_xml_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2011 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/tools/gyp/pylib/gyp/flock_tool.py b/tools/gyp/pylib/gyp/flock_tool.py
index b38d866..fdf9785 100644
--- a/tools/gyp/pylib/gyp/flock_tool.py
+++ b/tools/gyp/pylib/gyp/flock_tool.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2011 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/tools/gyp/pylib/gyp/generator/msvs_test.py b/tools/gyp/pylib/gyp/generator/msvs_test.py
index c0b021d..0eb53ea 100644
--- a/tools/gyp/pylib/gyp/generator/msvs_test.py
+++ b/tools/gyp/pylib/gyp/generator/msvs_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/tools/gyp/pylib/gyp/generator/ninja.py b/tools/gyp/pylib/gyp/generator/ninja.py
index 0e8ae97..1b9eb2d 100644
--- a/tools/gyp/pylib/gyp/generator/ninja.py
+++ b/tools/gyp/pylib/gyp/generator/ninja.py
@@ -1746,7 +1746,7 @@ def _AddWinLinkRules(master_ninja, embed_manifest):
return '%(python)s gyp-win-tool link-with-manifests $arch %(embed)s ' \
'%(out)s "%(ldcmd)s" %(resname)s $mt $rc "$intermediatemanifest" ' \
'$manifests' % {
- 'python': sys.executable,
+ 'python2': sys.executable,
'out': out,
'ldcmd': ldcmd,
'resname': resource_name,
diff --git a/tools/gyp/pylib/gyp/generator/ninja_test.py b/tools/gyp/pylib/gyp/generator/ninja_test.py
index 1767b2f..5c75cc3 100644
--- a/tools/gyp/pylib/gyp/generator/ninja_test.py
+++ b/tools/gyp/pylib/gyp/generator/ninja_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/tools/gyp/pylib/gyp/generator/xcode.py b/tools/gyp/pylib/gyp/generator/xcode.py
index 482b53a..b2e2d6f 100644
--- a/tools/gyp/pylib/gyp/generator/xcode.py
+++ b/tools/gyp/pylib/gyp/generator/xcode.py
@@ -281,7 +281,7 @@ class XcodeProject(object):
command_prefix = ''
if serialize_all_tests:
command_prefix = \
-"""python -c "import fcntl, subprocess, sys
+"""python2 -c "import fcntl, subprocess, sys
file = open('$TMPDIR/GYP_serialize_test_runs', 'a')
fcntl.flock(file.fileno(), fcntl.LOCK_EX)
sys.exit(subprocess.call(sys.argv[1:]))" """
diff --git a/tools/gyp/pylib/gyp/generator/xcode_test.py b/tools/gyp/pylib/gyp/generator/xcode_test.py
index 260324a..77a5687 100644
--- a/tools/gyp/pylib/gyp/generator/xcode_test.py
+++ b/tools/gyp/pylib/gyp/generator/xcode_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2013 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/tools/gyp/pylib/gyp/input_test.py b/tools/gyp/pylib/gyp/input_test.py
index 4234fbb..110627e 100644
--- a/tools/gyp/pylib/gyp/input_test.py
+++ b/tools/gyp/pylib/gyp/input_test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright 2013 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/tools/gyp/pylib/gyp/mac_tool.py b/tools/gyp/pylib/gyp/mac_tool.py
index eeeaceb..c83820a 100644
--- a/tools/gyp/pylib/gyp/mac_tool.py
+++ b/tools/gyp/pylib/gyp/mac_tool.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
diff --git a/tools/gyp/pylib/gyp/win_tool.py b/tools/gyp/pylib/gyp/win_tool.py
index bb6f1ea..e3d244a 100644
--- a/tools/gyp/pylib/gyp/win_tool.py
+++ b/tools/gyp/pylib/gyp/win_tool.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
@@ -144,7 +144,7 @@ class WinTool(object):
# first and only link. We still tell link to generate a manifest, but we
# only use that to assert that our simpler process did not miss anything.
variables = {
- 'python': sys.executable,
+ 'python2': sys.executable,
'arch': arch,
'out': out,
'ldcmd': ldcmd,
diff --git a/tools/gyp/samples/samples b/tools/gyp/samples/samples
index 804b618..0139666 100644
--- a/tools/gyp/samples/samples
+++ b/tools/gyp/samples/samples
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python2
# Copyright (c) 2009 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/tools/gyp/setup.py b/tools/gyp/setup.py
index 75a4255..e4ec8ba 100644
--- a/tools/gyp/setup.py
+++ b/tools/gyp/setup.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2009 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/tools/gyp/tools/emacs/testdata/media.gyp b/tools/gyp/tools/emacs/testdata/media.gyp
index 29300fe..c10cdd1 100644
--- a/tools/gyp/tools/emacs/testdata/media.gyp
+++ b/tools/gyp/tools/emacs/testdata/media.gyp
@@ -987,7 +987,7 @@
'<(SHARED_INTERMEDIATE_DIR)/media/jni/media_player_listener_jni.h',
],
'action': [
- 'python',
+ 'python2',
'<(DEPTH)/base/android/jni_generator/jni_generator.py',
'-o',
'<@(_inputs)',
diff --git a/tools/gyp/tools/emacs/testdata/media.gyp.fontified b/tools/gyp/tools/emacs/testdata/media.gyp.fontified
index 962b7b2..0ef99fc 100644
--- a/tools/gyp/tools/emacs/testdata/media.gyp.fontified
+++ b/tools/gyp/tools/emacs/testdata/media.gyp.fontified
@@ -988,7 +988,7 @@
'<(SHARED_INTERMEDIATE_DIR)/media/jni/media_player_listener_jni.h',
],
'action': [
- 'python',
+ 'python2',
'<(DEPTH)/base/android/jni_generator/jni_generator.py',
'-o',
'<@(_inputs)',
diff --git a/tools/gyp/tools/graphviz.py b/tools/gyp/tools/graphviz.py
index 326ae22..553a101 100644
--- a/tools/gyp/tools/graphviz.py
+++ b/tools/gyp/tools/graphviz.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2011 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/tools/gyp/tools/pretty_gyp.py b/tools/gyp/tools/pretty_gyp.py
index c51d358..262a0b3 100644
--- a/tools/gyp/tools/pretty_gyp.py
+++ b/tools/gyp/tools/pretty_gyp.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/tools/gyp/tools/pretty_sln.py b/tools/gyp/tools/pretty_sln.py
index ca8cf4a..13aef67 100644
--- a/tools/gyp/tools/pretty_sln.py
+++ b/tools/gyp/tools/pretty_sln.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/tools/gyp/tools/pretty_vcproj.py b/tools/gyp/tools/pretty_vcproj.py
index 6099bd7..41530a8 100644
--- a/tools/gyp/tools/pretty_vcproj.py
+++ b/tools/gyp/tools/pretty_vcproj.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
# Copyright (c) 2012 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
diff --git a/tools/gyp_node.py b/tools/gyp_node.py
index 8de046a..df0298d 100644
--- a/tools/gyp_node.py
+++ b/tools/gyp_node.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/python2
import os
import sys
diff --git a/tools/icu/icu-generic.gyp b/tools/icu/icu-generic.gyp
index 9d466ac..9d146f5 100644
--- a/tools/icu/icu-generic.gyp
+++ b/tools/icu/icu-generic.gyp
@@ -251,7 +251,7 @@
'action_name': 'icutrim',
'inputs': [ '<(icu_data_in)', 'icu_small.json' ],
'outputs': [ '<(SHARED_INTERMEDIATE_DIR)/icutmp/icudt<(icu_ver_major)<(icu_endianness).dat' ],
- 'action': [ 'python',
+ 'action': [ 'python2',
'icutrim.py',
'-P', '../../<(CONFIGURATION_NAME)',
'-D', '<(icu_data_in)',
@@ -332,7 +332,7 @@
'action_name': 'icutrim',
'inputs': [ '<(icu_data_in)', 'icu_small.json' ],
'outputs': [ '<(SHARED_INTERMEDIATE_DIR)/icutmp/icudt<(icu_ver_major)<(icu_endianness).dat' ],
- 'action': [ 'python',
+ 'action': [ 'python2',
'icutrim.py',
'-P', '<(PRODUCT_DIR)',
'-D', '<(icu_data_in)',
diff --git a/tools/icu/icutrim.py b/tools/icu/icutrim.py
index 517bf39..bc1802b 100644
--- a/tools/icu/icutrim.py
+++ b/tools/icu/icutrim.py
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python2
#
# Copyright (C) 2014 IBM Corporation and Others. All Rights Reserved.
#
diff --git a/tools/icu/shrink-icu-src.py b/tools/icu/shrink-icu-src.py
index d0c82d8..31c395c 100644
--- a/tools/icu/shrink-icu-src.py
+++ b/tools/icu/shrink-icu-src.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
import optparse
import os
import re
diff --git a/tools/install.py b/tools/install.py
index 4f15537..e61d71a 100644
--- a/tools/install.py
+++ b/tools/install.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
import errno
import json
diff --git a/tools/js2c.py b/tools/js2c.py
index 40c30cc..fe19598 100644
--- a/tools/js2c.py
+++ b/tools/js2c.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2006-2008 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff --git a/tools/mkssldef.py b/tools/mkssldef.py
index 8354e57..d44a456 100644
--- a/tools/mkssldef.py
+++ b/tools/mkssldef.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
from __future__ import print_function
import re
diff --git a/tools/specialize_node_d.py b/tools/specialize_node_d.py
index bb5ef5a..bfa580e 100644
--- a/tools/specialize_node_d.py
+++ b/tools/specialize_node_d.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# specialize_node_d.py output_file src/node.d flavor arch
diff --git a/tools/test.py b/tools/test.py
index 2613ad5..64276d6 100644
--- a/tools/test.py
+++ b/tools/test.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
#
# Copyright 2008 the V8 project authors. All rights reserved.
# Redistribution and use in source and binary forms, with or without
diff --git a/deps/npm/node_modules/node-gyp/lib/configure.js b/deps/npm/node_modules/node-gyp/lib/configure.js
index 4e06529..73eb0bd 100644
--- a/deps/npm/node_modules/node-gyp/lib/configure.js
+++ b/deps/npm/node_modules/node-gyp/lib/configure.js
@@ -44,7 +44,7 @@ function configure (gyp, argv, callback) {
function getNodeDir () {
// 'python' should be set by now
process.env.PYTHON = python
if (gyp.opts.nodedir) {
@@ -321,7 +321,7 @@ function findPython (python, callback) {
if (err) {
log.verbose('`which` failed', python, err)
if (python === 'python2') {
- python = 'python'
+ python = 'python2'
return checkPython()
}
if (win) {
@@ -44,7 +44,7 @@ function configure (gyp, argv, callback) {
function getNodeDir () {
- // 'python' should be set by now
+ // 'python2' should be set by now
process.env.PYTHON = python
if (gyp.opts.nodedir) {
--
2.9.1